==> clash-ghc-1.8.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-83ozn4cKMNn32lKem0asQk
key:                  clash-ghc-1.8.2-83ozn4cKMNn32lKem0asQk
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  bcb5f284489fe02b8d4e1debe35795ed
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-83ozn4cKMNn32lKem0asQk
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-2N6dnvq9XtZ3zxBJlzXD0A
    clash-prelude-1.8.2-AVo8XODc2ymCvnO4bj1LG8 containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-GLSgophAXHdJnn9BzoNHrD filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-BauEmPaXdw51ACHPp3UTkh
    ghc-typelits-knownnat-0.7.9-28v54AS8fke793YJWszGYV
    ghc-typelits-natnormalise-0.7.9-LVt00GvRj263UkNuQgnrtT ghci-9.4.8
    hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa haskeline-0.8.2
    lens-5.3-8ZK9QDANmBT9CZTQ77OGiP mtl-2.2.2
    primitive-0.9.0.0-1uQl5SMm5FQ52SaicTkt1Y process-1.6.18.0
    reflection-2.1.9-LLavOV8Wr6KWM4Lf6lgoi
    split-0.2.5-KlKHd5o1KWaBkefamTdKTk
    string-interpolate-0.3.4.0-6aj84RoVjugEmrEE02FA3Z
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-4BzKByujp41Ba8BKx5xnLI
    unix-2.7.3 unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.8.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-DEBTkWC2fTP34riWC5ghic
key:                  clash-ghc-1.8.2-DEBTkWC2fTP34riWC5ghic
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  98f4000225d614ce8131ee827b0756aa
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-DEBTkWC2fTP34riWC5ghic
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-1hNPqV50AQPEEp7izeuiX6
    clash-prelude-1.8.2-CjJ9WUUd9Tcx6rcBtDoYV containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-EsSkYAqLUuXHsKZqBfQYTX filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-FznaZC2I0Io9Hjh3Q8vz2H
    ghc-typelits-knownnat-0.7.9-AF4l6kRpPz35qjT4G5mxfB
    ghc-typelits-natnormalise-0.7.9-HXokjDMOk3j8EEqUzKeAG5 ghci-9.4.8
    hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt haskeline-0.8.2
    lens-5.3-4eslcvGQhMj5JgydAUw2Le mtl-2.2.2
    primitive-0.9.0.0-AqOaxoERoHJDqDj73ogtnE process-1.6.18.0
    reflection-2.1.9-IVKwTvUCNyPIsKRBtC7jQG
    split-0.2.5-9yRmZJdLmWeEyOIWbrT71c
    string-interpolate-0.3.4.0-AYRGxzkvhA6CUqaaejlTHO
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-CVBButb05by4R8qpMAO86S
    unix-2.7.3 unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
